@@ -3,7 +3,7 @@
 #
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2017 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -25,16 +25,13 @@ from . import utils
 import sys
 import mailbox
 import email
-import email.parser
 import email.errors
 import io
 import glob
 import os
 import re
-import time
 import urllib.request, urllib.parse, urllib.error
 import textwrap
-import pprint
 # SOAP interface to Debian BTS
 import debianbts
 from collections import defaultdict
@@ -74,7 +71,7 @@ SEVERITIES = {
     policy violations may be 'normal,' 'minor,' or 'wishlist' bugs.
     (Package maintainers may also designate other bugs as 'serious' and thus
     release-critical; however, end users should not do so.). For the canonical
-    list of issues worthing a serious severity you can refer to this webpage:
+    list of issues deserving a serious severity you can refer to this webpage:
     http://release.debian.org/testing/rc_policy.txt .""",
     'important': """a bug which has a major effect on the usability
     of a package, without rendering it completely unusable to
@@ -171,8 +168,8 @@ debother = {
     'cdimage.debian.org': 'CD Image issues',
     'cdrom': 'Installation system',
     'cloud.debian.org': 'Issues involving Debian images for public/private clouds',
+    'contributors.debian.org': 'Issues with the Debian Contributors Website and coordination of maintenance',
     'd-i.debian.org': 'Issues regarding the d-i.debian.org service and general Debian Installer tasks',
-    'debian-maintainers': 'Problems and requests related to Debian Maintainers',
     'debian-i18n': 'Requests regarding Internationalization (i18n) of the distribution',
     'debian-live': 'General problems with Debian Live systems',
     'ftp.debian.org': 'Problems with the FTP site and Package removal requests',
@@ -241,7 +238,7 @@ def handle_debian_ftp(package, bts, ui, fromaddr, timeout, online=True, http_pro
     if tag == 'other':
         return
     else:
-        prompt = 'Please enter the name of the package: '
+        prompt = 'Please enter the name of the package (either source of binary package): '
         package = ui.get_string(prompt)
         if not package:
             ui.log_message('You seem to want to report a generic bug, not request a removal\n')
@@ -264,14 +261,13 @@ def handle_debian_ftp(package, bts, ui, fromaddr, timeout, online=True, http_pro
                        'n': 'Exit without filing a report.'})
             if cont == 'n':
                 sys.exit(1)
-        else:
-            # don't try to convert it to source if it's an 'override'
-            if tag != 'override':
-                package = info[12] or package
-            # get package section and priority, for override
-            section, priority = info[16], info[10]
+
+        section, priority = info[16], info[10]
 
     if tag == 'override':
+        headers.append('X-Debbugs-CC: debian-boot@lists.debian.org')
+        ui.log_message('Your report will be carbon-copied to debian-boot.\n')
+
         # we handle here the override change request
         new_section = ui.menu('Select the new section', {
             'admin': "", 'cli-mono': "", 'comm': "", 'database': "",
@@ -416,7 +412,7 @@ def handle_debian_release(package, bts, ui, fromaddr, timeout, online=True, http
                       'britney': "testing migration script bugs",
                       'transition': "transition tracking",
                       'unblock': "unblock requests",
-                      oldstable_pu: "%s proposed updates requests" % oldstable,
+                      #oldstable_pu: "%s proposed updates requests" % oldstable,
                       stable_pu: "%s proposed updates requests" % stable,
                       'rm': "Stable/Testing removal requests",
                       'other': "None of the other options",
@@ -1157,9 +1153,7 @@ def get_report(number, timeout, system='debian', mirrors=None,
         # add Date/Subject/From headers to the msg bodies
         bodies = []
         for l in log:
-            f = email.parser.FeedParser()
-            f.feed(l['header'])
-            h = f.close()
+            h = l['message']
             hdrs = []
             for i in ['Date', 'Subject', 'From']:
                 if i in h:
