@@ -1,7 +1,7 @@
 # reportbug_submit module - email and GnuPG functions
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2006 Chris Lawrence
-#   Copyright (C) 2008-2017 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -144,7 +144,7 @@ def mime_attach(body, attachments, charset, body_charset=None):
             continue
         ctype = None
         cset = charset
-        info = Popen(['file', '--mime', '--brief', attachment],
+        info = Popen(['file', '--mime', '--brief', '--dereference', attachment],
                      stdout=PIPE, stderr=STDOUT).communicate()[0].decode('ascii')
         if info:
             match = re.match(r'([^;, ]*)(,[^;]+)?(?:; )?(.*)', info)
@@ -482,7 +482,7 @@ receive the bug tracking number via email; you may then send any extra
 information to %s (e.g. %s), where n is the bug number.  Normally you
 will receive an acknowledgement via email including the bug report number
 within an hour; if you haven't received a confirmation, then the bug reporting process failed at some point (reportbug or MTA failure, BTS maintenance, etc.).\n""",
-            (sysinfo['email'] % 'n'), (sysinfo['email'] % '999999'))
+            (sysinfo['email'] % 'n'), (sysinfo['email'] % 'nnnnnn'))
 
     # If we've stored more than one copy of the message, delete the
     # one without the SMTP headers.
